@@ -221,7 +221,7 @@ class FastScanCommand:
                 self.start_detector_acquisition()
                 self._controller.extVcm._device.start_x_signal_generator(self.amplitude_x, 25, 0, 0)
                 self._controller.extVcm._device.start_y_signal_generator(self.amplitude_y, 1, 0, 0)
-                self._controller.extVcm.register_record_callback(self.record_callback)
+                self._controller.extVcm._device.register_record_callback(self.record_callback)
                 for wavelength in self.wavelengths:
                     self._completedWl += 1
                     if self.stopped.is_set():
@@ -287,8 +287,8 @@ class FastScanCommand:
         finally:
             self.stop()
             self._controller.stop_all_pulsing()
-            self._controller.extVcm.reset_static_input()
-            self._controller.extVcm.unregister_record_callback(self.record_callback)
+            self._controller.extVcm._device.reset_static_input()
+            self._controller.extVcm._device.unregister_record_callback(self.record_callback)
 
     def stop(self):
         self.stopped.set()
